@@ -1,5 +1,5 @@
 <?php
-/* $Id: arabic-utf-8.inc.php,v 2.39 2004/09/22 12:53:50 nijel Exp $ */
+/* $Id: arabic-utf-8.inc.php,v 2.78 2005/07/29 17:03:05 lem9 Exp $ */
 
 /**
  * Original translation to Arabic by Fisal <fisal77 at hotmail.com>
@@ -114,7 +114,7 @@ $strCharsetOfFile = 'شيفرة أحرف الملف:';
 $strCharsets = 'مجموعات المحارف';
 $strCharsetsAndCollations = 'مجموعات المحارف وCollations';
 $strCheckAll = 'إختر الكل';
-$strCheckOverhead = 'تحقق من overheaded';
+$strCheckOverhead = 'تحقق من overhead';
 $strCheckPrivs = 'تحقق من الصلاحيات';
 $strCheckPrivsLong = 'تحقق من الصلاحيات لقاعدة بيانات &quot;%s&quot;.';
 $strCheckTable = 'التحقق من الجدول';
@@ -387,7 +387,6 @@ $strNone = 'لاشئ';
 $strNotNumber = 'هذا ليس رقم!';
 $strNotOK = 'ليس صالحاً';
 $strNotSet = 'الجدول <b>%s</b> غير موجود أو محدد في %s';
-$strNotValidNumber = ' هذا ليس عدد صف صحيح!';
 $strNull = 'خالي';
 $strNumSearchResultsInTable = '%s مطابقة في الجدول <i>%s</i>';
 $strNumSearchResultsTotal = '<b>المجموع:</b> <i>%s</i>مطابقة';
@@ -464,7 +463,6 @@ $strPrivDescUsage = 'لا صلاحيات.';
 $strPrivileges = 'الإمتيازات';
 $strPrivilegesReloaded = 'تم إعادة قراءة الصلاحيات بنجاح.';
 $strProcesslist = 'سرد العمليّات';
-$strProperties = 'خصائص';
 $strPutColNames = 'ضع أسماء الحقول في السطر الأول';
 
 $strQBE = 'إستعلام بواسطة مثال';
@@ -630,7 +628,6 @@ $strTransformation_text_plain__formatted = 'يُبقي التنسيق الأصل
 $strTransformation_text_plain__imagelink = 'تظهر صورة ورابط، يتحوي الحقل على إسم الملف، الخيار الأول هو سابقة مثل "http://domain.com/"، والخيار الثاني هو العرض بالبكسل، والثالث هو الارتفاع.';
 $strTransformation_text_plain__link = 'تظهر رابطاً، الحقل يحتوي إسم الملف، والخيار الأول هو سابقة مثل "http://domain.com/"، والخيار الثاني هو العنوان للرابط.';
 $strTransformation_text_plain__substr = 'يظهر فقط جزءً من النص. الخيار الأول يحدد مكان بدء ظهور النص )صفر بشكل افتراضي(. الخيار الثاني هو تعديل كمّ النص المسترجع. إن كان فارغاً، يسترجع كل النص الباقي. الخيار الثالث يعرف أي من الأحرف سوف تضاف إلى المخرجات عند استرجاع جزء من النص )... بشكل افتراضي(.';
-$strTransformation_text_plain__unformatted = 'يظهر نص شيفرة HTML كوحدات. لا يظهر أي تنسيق HTML.';
 $strTruncateQueries = 'إحذف الاستعلامات المعروضة';
 $strTurkish = 'التركية';
 $strType = 'النوع';
@@ -726,4 +723,102 @@ $strTraditionalSpanish = 'Traditional Spanish';  //to translate
 $strSlovak = 'Slovak';  //to translate
 $strMySQLConnectionCollation = 'MySQL connection collation';  //to translate
 $strPersian = 'Persian';  //to translate
+$strAddFields = 'Add %s field(s)';  //to translate
+$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate
+$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
+$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
+$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
+$strBinLogName = 'Log name';  //to translate
+$strBinLogPosition = 'Position';  //to translate
+$strBinLogEventType = 'Event type';  //to translate
+$strBinLogServerId = 'Server ID';  //to translate
+$strBinLogOriginalPosition = 'Original position';  //to translate
+$strBinLogInfo = 'Information';  //to translate
+$strBinaryLog = 'Binary log';  //to translate
+$strSelectBinaryLog = 'Select binary log to view';  //to translate
+$strDBCopy = 'Copy database to';  //to translate
+$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
+$strSwitchToDatabase = 'Switch to copied database';  //to translate
+$strPasswordHashing = 'Password Hashing';  //to translate
+$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
+$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
+$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
+$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
+$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
+$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
+$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
+$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
+$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
+$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
+$strAfterInsertNext = 'Edit next row';  //to translate
+$strView = 'View';  //to translate
+$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
+$strEngines = 'Engines';  //to translate
+$strStorageEngines = 'Storage Engines';  //to translate
+$strStorageEngine = 'Storage Engine';  //to translate
+$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
+$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
+$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
+$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
+$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
+$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
+$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
+$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
+$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
+$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
+$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
+$strMyISAMRepairThreads = 'Repair threads';  //to translate
+$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
+$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
+$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
+$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
+$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
+$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
+$strVersionInformation = 'Version information';  //to translate
+$strInnoDBDataHomeDir = 'Data home directory';  //to translate
+$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
+$strInnoDBDataFilePath = 'Data files';  //to translate
+$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
+$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
+$strBufferPool = 'Buffer Pool';  //to translate
+$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
+$strDataPages = 'Pages containing data';  //to translate
+$strFreePages = 'Free pages';  //to translate
+$strBusyPages = 'Busy pages';  //to translate
+$strDirtyPages = 'Dirty pages';  //to translate
+$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
+$strLatchedPages = 'Latched pages';  //to translate
+$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
+$strReadRequests = 'Read requests';  //to translate
+$strWriteRequests = 'Write requests';  //to translate
+$strBufferReadMisses = 'Read misses';  //to translate
+$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
+$strBufferWriteWaits = 'Write waits';  //to translate
+$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
+$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
+$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
+$strHTMLWord = 'Microsoft Word 2000';  //to translate
+$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
+$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
+$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
+$strInnoDBPages = 'pages';  //to translate
+$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
+$strPrivDescCreateView = 'Allows creating new views.';  //to translate
+$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
+$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
+$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
+$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
+$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
+$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
+$strGeneratePassword = 'Generate Password';  //to translate
+$strGenerate = 'Generate';  //to translate
+$strCopy = 'Copy';  //to translate
+$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
+$strInvalidFieldCount = 'Table must have at least one field.';  //to translate
+$strInvalidRowNumber = '%d is not valid row number.';  //to translate
+$strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
+$strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
+$strAndThen = 'and then';  //to translate
 ?>
