@@ -1,17 +1,17 @@
 <?php
-/* $Id: turkish-utf-8.inc.php,v 2.41 2004/09/22 12:53:52 nijel Exp $ */
+/* $Id: turkish-utf-8.inc.php,v 2.80.2.1 2005/09/02 19:55:48 lem9 Exp $ */
 
-//son güncelleme:07.08.2004 (in trapezunta)
+// son güncelleme:28.08.2005 (in nova roma)
 // Türkçe Çeviri ® Bora Alioğlu
-// mail: boralioglu@yahoo.co.uk
+// mail: boralioglu[at]gmail.{com}
 // icq uin: 20940178
 // #######################################################
 // çeviri hakkındaki her türlü düzeltme ve önerileriniz
 // için benimle temasa geçebilirsiniz...
 // #######################################################
-// son güncelleme:22.09.04 (on the way to the constantinople)
+// son güncelleme:28.08.2005 (in nova roma)
 //
-//                                       "ego lente festino"
+//                                       "o temporas o mores"
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
@@ -32,6 +32,22 @@ $datefmt = '%B %d, %Y at %I:%M %p';
 
 $timespanfmt = '%s gün, %s saat, %s dakika ve %s saniye';
 
+//new translations begin here
+
+ 
+
+ 
+
+ 
+
+ 
+
+ 
+
+ 
+
+ 
+
 $strAbortedClients = 'İptal edildi';
 $strAbsolutePathToDocSqlDir = 'Lütfen web sunucusu üzerinde docSQL dizinine giden tam yolu giriniz  ';
 $strAccessDenied = 'Erişim engellendi';
@@ -44,6 +60,7 @@ $strAddDeleteRow = 'Kriter satırı Ekle/Sil';
 $strAddDropDatabase = '<b>DROP DATABASE</b> ekle';
 $strAddedColumnComment = 'Sütun için eklenmiş yorum';
 $strAddedColumnRelation = 'Sütun için eklenmiş ilişki';
+$strAddFields = '%s alan(lar) ekle';
 $strAddHeaderComment = 'Başlığa yorum ekle (\\n satır atlar)';
 $strAddIfNotExists = 'IF NOT EXISTS ekle';
 $strAddIntoComments = 'Yorumlara ekle';
@@ -58,17 +75,20 @@ $strAdministration = 'Yönetim';
 $strAffectedRows = 'Etkilenen satırlar:';
 $strAfterInsertBack = 'Önceki sayfaya geri dön';
 $strAfterInsertNewInsert = 'Yeni kayıt ekle';
+$strAfterInsertNext = 'Sonraki satırı düzenle';
 $strAfterInsertSame = 'Bu sayfaya geri dön';
 $strAfter = '%s tablosundan sonra';
 $strAllTableSameWidth = 'Bütün tabloları aynı genişlikte göster';
 $strAll = 'Tümü';
 $strAlterOrderBy = 'Tablo sıralamasını şuna göre değiştir';
 $strAnalyzeTable = 'Tabloyu analiz et';
+$strAndThen = 've';	
 $strAnd = 'Ve';
 $strAnIndex = '%s üzerinde yeni bir indeks eklendi';
 $strAny = 'Herhangi';
 $strAnyHost = 'Herhangi sunucu';
 $strAnyUser = 'Herhangi kullanıcı';
+$strApproximateCount = 'Tahmini olmalı. Ayrıntılı bilgi için 3.11 FAQ\' süne bakınız ';
 $strAPrimaryKey = '%s üzerinde birincil indeks eklendi';
 $strArabic = 'Arapça';
 $strArmenian = 'Ermenice';
@@ -76,7 +96,7 @@ $strAscending = 'Artan';
 $strAtBeginningOfTable = 'Tablo başında';
 $strAtEndOfTable = 'Tablo sonunda';
 $strAttr = 'Özellikler';
-$strAutodetect = 'Otomatik tanıma';
+$strAutodetect = 'Otomatik';
 $strAutomaticLayout = 'Otomatik düzen';
 
 $strBack = 'Geri';
@@ -85,6 +105,13 @@ $strBeginCut = 'BEGIN CUT';
 $strBeginRaw = 'BEGIN RAW';
 $strBinary = 'Binari';
 $strBinaryDoNotEdit = 'Binari - düzenlemeyiniz';
+$strBinaryLog = 'Binary kayıt';  
+$strBinLogEventType = 'Kayıt olay tipi';  
+$strBinLogInfo = 'Bilgi';  
+$strBinLogName = 'Kayıt ismi';
+$strBinLogOriginalPosition = 'Orjinal kayıt yeri';
+$strBinLogPosition = 'Kayıt yeri';  
+$strBinLogServerId = 'Sunucu ID\`si'; 
 $strBookmarkAllUsers = 'Bütün kullanıcıların bu bookmark\'a erişimlerine izin ver';
 $strBookmarkDeleted = 'Bookmark silindi.';
 $strBookmarkLabel = 'Etiket';
@@ -94,9 +121,12 @@ $strBookmarkThis = 'Bu SQL sorgusunu işaretle';
 $strBookmarkView = 'Sadece gözat';
 $strBrowseForeignValues = 'Foreign(yabancı) değerleri tara';
 $strBrowse = 'Tara';
+$strBufferPool = 'Ara Bellek Havuzu';  
+$strBufferPoolUsage = 'Ara Bellek Havuzu Kullanımı';   
 $strBulgarian = 'Bulgarca';
+$strBusyPages = 'Meşgul Sayfalar';   
 $strBzError = 'phpMyAdmin dump dosyasını  bu php versiyonundaki bozuk bir Bz2 uzantısı nedeniyle sıkıştırımadı. phpMyAdmin dizinindeki configurasyon dosyası içindeki  <code>$cfg[\'BZipDump\']</code>  yönergesini <code>FALSE</code> \'a değiştirmeniz gerekmektedir. Bz2 sıkıştırma özelliklerini kullanmak istiyorsanız ,bir sonraki php sürümüne güncelleme yapmanız gerekmektedir.php hata raporu %s\' e bakınız ';
-$strBzip = '"bzipped"';
+$strBzip = '"bzip"';
 
 $strCalendar = 'Takvim';
 $strCannotLogin = 'MySQL seçenekleri';
@@ -120,21 +150,23 @@ $strChangeDisplay = 'Görmek istediğiniz alanı seçiniz';
 $strChangePassword = 'Şifre Değiştir';
 $strCharset = 'Karakter seti';
 $strCharsetOfFile = 'Dosyanın karakter seti:';
-$strCharsetsAndCollations = 'Karakter setleri ve  karşılaştırmalar(collation)';
+$strCharsetsAndCollations = 'Karakter setleri ve  karşılaştırmalar';
 $strCharsets = 'Karakter setleri';
 $strCheckAll = 'Tümünü seç';
 $strCheckOverhead = 'Baştan aşağıya kontrol et';
-$strCheckPrivs = 'İmtiyazları kontrol et';
+$strCheckOverhead = 'Fazlalık (Overhead) tabloları kontrol et';
 $strCheckPrivsLong = '&quot;%s&quot; veritabanı için yetkileri kontrol et.';
+$strCheckPrivs = 'İmtiyazları kontrol et';
 $strCheckTable = 'Tabloyu kontrol et';
 $strChoosePage = 'Lütfen düzenlemek istediğiniz sayfayı seçin';
 $strColComFeat = 'Sütun yorumları gösteriliyor';
-$strCollation = 'Karşılaştırma(Collation)';
+$strCollation = 'Karşılaştırma';
 $strColumnNames = 'Sütun adları';
 $strColumnPrivileges = 'Sütuna özgü yetkiler';
 $strCommand = 'Komut';
 $strCommentsForTable = 'TABLO YORUMLARI';
 $strComments = 'Sütun yorum,ilişki ve MIME tiplerini içer.';
+$strCompatibleHashing = 'MySQL&nbsp;4.0 uyumlu'; 
 $strCompleteInserts = 'Her INSERT komutunda sütun adlarını ekle';
 $strCompression = 'Sıkıştırma';
 $strConfigFileError ='phpMyAdmin konfigurasyon dosyanızı okuyamadı....<br /> Bu php yorumlama hatası bulduğu zaman veya dosyayı bulamadığı zaman meydana gelebilir..<br /> Lütfen aşağıdaki linki kullanarak dosyayı direkt olarak çağırın ve aldığınız php hata mesajlarını okuyunuz.Çoğu durumda herhangi bir yerde tırnak veya noktalı virgül eksiktir<br /> Boş bir sayfayla karşılaşırsanız ,herşey yolunda demektir.';
@@ -144,10 +176,13 @@ $strConnections = 'Bağlantılar';
 $strConstraintsForDumped = 'Dökümü yapılmış tablolar için kısıtlamalar';
 $strConstraintsForTable = 'Tablo için kısıtlamalar';
 $strCookiesRequired = 'Cookieler açık olmalıdır.';
+$strCopyDatabaseOK = '%s veritabanı %s\` e kopyalandı.'; 
+$strCopy = 'Kopyala';
 $strCopyTableOK = '%s tablosu %s üzerine kopyalandı.';
 $strCopyTableSameNames = 'Tabloyu aynısına kopyalayamıyor!';
 $strCopyTable = 'Tabloyu (veritabanı<b>.</b>tablo) kopyala :';
 $strCouldNotKill = 'phpMyAdmin  %s işlemini kapatamadı. Büyük ihtimalle daha önceden kapatılmış.';
+$strCreateDatabaseBeforeCopying = 'Kopyalamadan önce CREATE DATABASE (Veritabanı Yarat)';
 $strCreate = 'Git';
 $strCreateIndex = '%s. sütunda yeni bir indeks oluştur.';
 $strCreateIndexTopic = 'Yeni bir indeks oluştur';
@@ -177,10 +212,12 @@ $strDatabases = 'Veritabanları';
 $strDatabase = 'Veritabanı';
 $strDataDict = 'Veri sözlüğü';
 $strDataOnly = 'Sadece veri';
+$strDataPages = 'Veri içeren sayfalar';   
 $strData = 'Veri';
 $strDBComment = 'Veritabanı yorumu:';
-$strDBGContext = 'İçerik';
+$strDBCopy = 'Veritabanını şuraya kopyala:';  
 $strDBGContextID = 'İçerik ID';
+$strDBGContext = 'İçerik';
 $strDBGHits = 'Girişler(hit)';
 $strDBGLine = 'Satır';
 $strDBGMaxTimeMs = 'Max zaman, ms';
@@ -191,6 +228,7 @@ $strDBGTotalTimeMs = 'Toplam zaman, ms';
 $strDbPrivileges = 'Veritabanına özgü yetkiler';
 $strDBRename = 'Veritabanını yeniden adlandır';
 $strDbSpecific = 'Veritabanına özgü';
+$strDefaultEngine = '%s bu MySQL sunucusunun üzerindeki varsayılan depolama motorudur.';   
 $strDefaultValueHelp = 'Varsayılan değerler için tırnak işareti veya slash koymak yerine tek değer giriniz.Mesela : a';
 $strDefault = 'Varsayılan';
 $strDefragment = 'Tabloyu birleştir';
@@ -205,6 +243,7 @@ $strDelOld = 'Sayfada kullanılmayan tablolara verilmiş referanslar bulunuyor.
 $strDescending = 'Azalan';
 $strDescription = 'Tanımlama';
 $strDictionary = 'sözlük';
+$strDirtyPages = 'Bozuk Sayfalar';  // not the actual translation i need some help
 $strDisabled = 'Etkin değil';
 $strDisableForeignChecks = 'Yabancı anahtar işaretlerini seçilemez kıl';
 $strDisplayFeat = 'Özellikleri Göster';
@@ -233,9 +272,13 @@ $strEncloseInTransaction = 'İşlemlerde dönüştürü ekle';
 $strEndCut = 'END CUT';
 $strEndRaw = 'END RAW';
 $strEnd = 'Son';
-$strEnglish = 'İngilizce';
+$strEngineAvailable = '%s bu MySQL sunucusu üzerinde bulunmaktadır.';  $strEngineUnsupported = 'Bu MySQL sunucusu %s depolama motorunu desteklememektedir.'; 
+$strEngineDisabled = '%s bu MySQL sunucusu için devre dışı bırakılmıştır.';
+$strEngines = 'Motorlar';   
 $strEnglishPrivileges = ' Not: MySQL  yetki adları İngilizce olarak belirtilmiştir ';
+$strEnglish = 'İngilizce';
 $strError = 'Hata';
+$strEscapeWildcards = '_ ve % jokerleri harfi harfine kullanılmak isteniyorsa \ ile beraber kullanılmalıdır.';
 $strEstonian = 'Estonyaca';
 $strExcelEdition = 'Excel tipi';
 $strExcelOptions = 'Excel ayarları';
@@ -248,7 +291,7 @@ $strExtra = 'Ekstra';
 $strFailedAttempts = 'Başarısız denemeler';
 $strField = 'Alan';
 $strFieldHasBeenDropped = '%s alanı kaldırılmıştır';
-$strFields = 'Alan Sayısı';
+$strFields = 'Alanlar';
 $strFieldsEmpty = ' Alan sayısı boş! ';
 $strFieldsEnclosedBy = 'Kapatma karakteri';
 $strFieldsEscapedBy = 'Kaçış karakteri';
@@ -263,11 +306,14 @@ $strFlushPrivilegesNote = 'Not: phpMyAdmin kullanıcıların yetkilerini direkt
 $strFlushTable = 'Tabloyu yeniden yükle("FLUSH")';
 $strFormat = 'Biçim';
 $strFormEmpty = 'Form\'da eksik değer !';
+$strFreePages = 'Serbest Sayfalar';   
 $strFullText = 'Tüm metinler';
 $strFunction = 'Fonksiyon';
 
 $strGenBy = 'üretildi:';
 $strGeneralRelationFeat = 'Genel ilişki özellikleri';
+$strGenerate = 'Oluştur';
+$strGeneratePassword = 'Şifre Oluştur';
 $strGenTime = 'Çıktı Tarihi';
 $strGeorgian = 'Gürcüce';
 $strGerman = 'Almanca';
@@ -277,7 +323,7 @@ $strGlobalValue = 'Global değer';
 $strGo = 'Git';
 $strGrantOption = 'Hak';
 $strGreek = 'Yunanca';
-$strGzip = '"gziplenmiş"';
+$strGzip = '"gzip"';
 
 $strHasBeenAltered = 'düzenlendi.';
 $strHasBeenCreated = 'yaratıldı.';
@@ -302,12 +348,22 @@ $strImportFiles = 'Dosyaları dönüştür';
 $strImportFinished = 'Dönüştürme bitti';
 $strIndexes = 'İndeksler';
 $strIndexHasBeenDropped = '%s indeks\'i silindi.';
-$strIndex = 'İndeks';
 $strIndexName = 'İndeks ismi :';
 $strIndexType = 'İndeks tipi :';
+$strIndexWarningMultiple = '`%s` sütunu için birden fazla %s anahtarı yaratıldı. ';
+$strIndexWarningPrimary = 'PRIMARY ve INDEX anahtarlarının ikisine birden `%s` sütunu için değer verilemez.';
+$strIndexWarningTable = '`%s` tablosunun indexleri ile ilgili sorunlar';
+$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';
+$strIndex = 'İndeks';
+$strInnoDBAutoextendIncrement = 'Artış miktarını otomatik olarak arttır';   
+$strInnoDBAutoextendIncrementDesc = ' Otomatik genişleyen tablo boyutu boş olduğunda otomatik genişleyen tablo boşluğunun boyutun artış miktarı.';  
+$strInnoDBDataFilePath = 'Veri dosyaları';  
+$strInnoDBDataHomeDirDesc = 'InnoDB veri dosyaları için dizin yolunun ortak kullanılan kısmı.'; 
+$strInnoDBDataHomeDir = 'Veri ana dizini ';  
 $strInnodbStat = 'InnoDB durumu';
 $strInsecureMySQL = 'Konfigurasyon dosyanız (şifresiz root) varsayılan MySQL yetki dosyasıyla aynen uyuşan ayarlar içeriyor.MySQL sunucunuz bu varsayılan ayarlarla çalışıyor,dışardan girişe açık,ve bu güvenlik açığını hemen düzeltmeniz gerekmektedir.';
 $strInsertAsNewRow = 'Yeni satır olarak ekle';
+$strInsertBookmarkTitle = 'Lütfen bookmark başlığını ekleyin'; 
 $strInsertedRowId = 'Satır id\'si eklendi:';
 $strInsertedRows = 'Eklenen satırlar:';
 $strInsert = 'Ekle';
@@ -317,6 +373,10 @@ $strInstructions = 'Talimatlar';
 $strInternalNotNecessary = '* InnoDb\'nin içinde zaten bir iç ilişki  var ise gerekli değildir.';
 $strInternalRelations = 'İç ilişkiler';
 $strInUse = 'kullanımda';
+$strInvalidColumnCount = 'Sütun sayısı sıfırdan büyük olmalı.';
+$strInvalidFieldAddCount = 'En azından bir alan eklemeniz gerekmektedir..';
+$strInvalidFieldCount = 'Tablonun en az bir alanı olmalı.';
+$strInvalidRowNumber = '%d geçerli bir satır sayısı değil.';
 
 $strJapanese = 'Japonca';
 $strJumpToDB = '&quot;%s&quot; veritabanına git.';
@@ -329,6 +389,7 @@ $strKill = 'Kapat';
 $strKorean = 'Korece';
 
 $strLandscape = 'Peyzaj';
+$strLatchedPages = 'Mandallanmış Sayfalar';  //also this
 $strLatexCaption = 'Tablo başlığı';
 $strLatexContent = '__TABLE__ tablosunun içeriği';
 $strLatexContinuedCaption = 'devam eden tablo başlığı';
@@ -356,8 +417,11 @@ $strLogout = 'Çıkış';
 $strLogPassword = 'Şifre:';
 $strLogServer = 'Sunucu';
 $strLogUsername = 'Kullanıcı Adı:';
+$strLongOperation = 'Bu işlem çok uzun sürebilir. Devam etmek istediğiniz emin misiniz?';
 
 $strMaximumSize = 'En büyük boyut: %s%s';
+$strMbExtensionMissing = 'mbstring PHP uzantısı bulunamadı ve multibyte karakter seti kullanmaktasınız. Eğer mbstring uzantısı bulunmazsa phpMyAdmin karakter dizilerini düzgün bir şekilde bölemeyeceği için beklenmeyen sonuçlar oluşabilir.';
+$strMbOverloadWarning = 'mbstring.func_overload PHP konfigürasyon dosyanızda etkinleştirilmiş durumda. Bu seçenek phpMyAdmin ile uyumsuzluk göstermekte ve bazı verilerin bozulmasına yol açabilir!';
 $strMIME_available_mime = 'Uygun MIME-tipleri';
 $strMIME_available_transform = 'Uygun dönüşümler';
 $strMIME_description = 'Tanımlama';
@@ -378,8 +442,19 @@ $strMoveTableSameNames = 'Tabloyu aynısına taşıyamıyor!';
 $strMoveTable = 'Tabloyu (veritabanı<b>.</b>tablo) taşı :';
 $strMultilingual = 'çoklu dil';
 $strMustSelectFile = 'Eklemek istediğiniz dosyayı seçmeniz gerekir.';
+$strMyISAMDataPointerSizeDesc = 'MAX_ROWS seçeneği belirtilmediği durumlarda MyISAM tabloları için CREATE TABLE komutuyla kullanılacak olan varsayılan işaretçi boyutu (Byte olarak).';  
+$strMyISAMDataPointerSize = 'Veri işaretçi boyutu';   
+$strMyISAMMaxExtraSortFileSizeDesc = 'Hızlı MyISAM indeksi oluşturulması sırasında kullanılan geçici dosya belirtilen boyutta anahtar önbellek kullanılması durumunda oluşacak olan dosyadan büyük olacaksa, anahtar önbellek metodunu seçiniz.';  
+$strMyISAMMaxExtraSortFileSize = 'İndeks oluşturmada kullanılan maksimum geçici dosyalar boyutu'; 
+$strMyISAMMaxSortFileSizeDesc = 'MySQL\in bir MyISAM indeksini yeniden oluştururken kullandığı geçici dosyanın maksimum boyutu (REPAIR TABLE, ALTER TABLE, ya da LOAD DATA INFILE sırasında).';  
+$strMyISAMMaxSortFileSize = 'Maksimum geçici sıralama dosyaları boyutu.';
+$strMyISAMRecoverOptions = 'Otomatik Kurtarma Modu';   $strMyISAMRecoverOptionsDesc = '-myisam-recover şeklinde sunucu başlangıç komutu olarak ayarlanabilen ve çöken MyISAM tablolarını otomatik olarak kurtarmak amacıyla kullanılan mod,.';   
+$strMyISAMRepairThreadsDesc = 'Bu değer 1\den büyükse, işlem sıralama yoluyla yapılan Onarım (Repair) sırasında MyISAM tablosu indeksleri (her bir indeks kendi işlemi içinde ) paralel olarak yaratılır. ';  
+$strMyISAMRepairThreads = 'İşlemleri Onar';   
+$strMyISAMSortBufferSizeDesc = 'Bir REPAIR TABLE komutuyla MyISAM indeksleri sıralanırken ya da CREATE INDEX ya da ALTER TABLE komutuyla indekslerin oluşturulması sırasında için ayrılan ara bellek miktarı.';  
+$strMyISAMSortBufferSize = 'Listeleme ara bellek boyutu';   
 $strMySQLCharset = 'MySQL karakter seti';
-$strMySQLConnectionCollation = 'MySQL bağlantı karşılaştırması(collation)';
+$strMySQLConnectionCollation = 'MySQL bağlantı karşılaştırması';
 $strMySQLReloaded = 'MySQL yeniden yüklendi.';
 $strMySQLSaid = 'MySQL çıktısı: ';
 $strMySQLServerProcess = ' MySQL %pma_s1%   %pma_s2%  üzerinde  %pma_s3% olarak çalışıyor';
@@ -390,9 +465,11 @@ $strMySQLShowVars = 'MySQL sistem değişkenlerini göster';
 $strName = 'İsim';
 $strNeedPrimaryKey = 'Bu tablo için birincil anahtar tanımlamanız gerekir.';
 $strNext = 'Sonraki';
+$strNoActivity = '%s veya daha fazla saniye boyunca hiçbir işlem yapılmadı, lütfen yeniden giriş yapınız';
 $strNoDatabasesSelected = 'Veritabanı seçilmedi.';
 $strNoDatabases = 'Veritabanı yok';
 $strNoDescription = 'Tanımlama yok';
+$strNoDetailsForEngine = 'Bu depolama motoru için detaylı durum bilgisi bulunmamaktadır.';   
 $strNoDropDatabases = '"DROP DATABASE" cümlesi burada kullanılamaz.';
 $strNoExplain = 'SQL açıklamasını yapma';
 $strNoFrames = 'phpMyAdmin frame destekli bir tarayıcı ile daha iyi çalışmaktadır...';
@@ -411,13 +488,14 @@ $strNoRights = 'Burada bulunmak için yeterli haklara sahip değilsiniz!';
 $strNoRowsSelected = 'Satır seçilmedi';
 $strNoSpace = '%s dosyasını kaydetmek için yeterli alan yok.';
 $strNoTablesFound = 'Veritabanında tablo bulunamadı.';
+$strNoThemeSupport = 'Tema desteği bulunmuyor,lütfen ayarları ve/veya %s dizinindeki temalarınızı kontrol ediniz';
 $strNotNumber = 'Lütfen bir sayı giriniz!';
 $strNotOK = 'Tamam değil';
 $strNotSet = '<b>%s</b> tablosu bulunamadı veya %s içinde tanımlanmadı';
-$strNotValidNumber = ' geçerli bir satır sayısı değil!';
 $strNoUsersFound = 'Kullanıcı(lar) bulunamadı.';
 $strNoValidateSQL = 'SQL doğrulamasını yapma';
 $strNull = 'Boş';
+$strNumberOfFields = 'Alan Sayısı';
 $strNumSearchResultsInTable = '<b><font color=\'blue\'>%s</font></b> ( <b>%s</b> tablosu içinde aramanıza uyan kayıt sayısı ) ';
 $strNumSearchResultsTotal = 'Toplam: %s eşleşim';
 $strNumTables = 'Tablolar';
@@ -434,11 +512,13 @@ $strOverhead = 'Kullanılamayan Veri';
 $strOverwriteExisting = 'Mevcut dosyaların üzerine yaz!';
 
 $strPageNumber = 'Sayfa numarası:';
+$strPagesToBeFlushed = 'Yeniden yüklenecek sayfaları göster (flush)'; 
 $strPaperSize = 'Kağıt boyu';
 $strPartialText = 'Kısmi Metinler';
 $strPasswordChanged = '%s için şifre başarıyla değiştirildi.';
 $strPasswordEmpty = 'Şifre alanı doldurulmadı!';
-$strPasswordNotSame = 'Girilen şifreler aynı değil!';
+$strPasswordHashing = 'Şifre Hash yöntemi';  
+$strPasswordNotSame = 'Girilen şifreler uyuşmuyor!';
 $strPassword = 'Şifre';
 $strPdfDbSchema = ' "%s" veritabanının şeması - Sayfa %s';
 $strPdfInvalidTblName = ' "%s" tablosu bulunamıyor !';
@@ -448,7 +528,7 @@ $strPerMinute = 'dakika başına';
 $strPerSecond = 'saniye başına';
 $strPersian = 'Farsça';
 $strPhoneBook = 'telefon defteri';
-$strPHP40203 = ' Ciddi bir multi-byte strings (mbstring) hatasına sahip olan PHP 4.2.3 kullanıyorsunuz,. PHP hata raporu 19404\' e bakınız. Bu sürümün phpMyAdmin\'le kullanılması önerilmez.';
+$strPHP40203 = ' Ciddi bir multi-byte karakter dizisi (mbstring) hatasına sahip olan PHP 4.2.3 kullanıyorsunuz,. PHP hata raporu 19404\' e bakınız. Bu sürümün phpMyAdmin\'le kullanılması önerilmez.';
 $strPhp = 'PHP kodu oluştur';
 $strPHPVersion = 'PHP Sürümü';
 $strPmaDocumentation = 'phpMyAdmin yardım';
@@ -493,10 +573,9 @@ $strPrivDescShutdown = 'Sunucunun kapatılmasına izin ver.';
 $strPrivDescSuper = 'Maksimum bağlantı sayısı aşılsa bile bağlanmasına izin ver;Global değişkenleri saptamak veya diğer kullanıcıların işlemlerini sonlandırmak  gibi  bir çok yönetim işlemi için gereklidir.';
 $strPrivDescUpdate = 'Veri değiştirilmesine izin ver.';
 $strPrivDescUsage = 'İmtiyaz yok.';
-$strPrivileges = 'İmtiyazlar';
 $strPrivilegesReloaded = 'Ayrıcalıklar başarıyla yüklendi.';
+$strPrivileges = 'İmtiyazlar';
 $strProcesslist = 'İşlem listesi';
-$strProperties = 'Özellikler';
 $strPutColNames = 'İlk satırda alan isimlerini koy';
 
 $strQBEDel = 'Del';
@@ -562,12 +641,13 @@ $strSearchNeedle = 'Aranacak kelime veya değerler ( joker: "%" ):';
 $strSearchOption1 = 'kelimelerin en azından biri';
 $strSearchOption2 = 'bütün kelimeler';
 $strSearchOption3 = 'tam eşleşim';
-$strSearchOption4 = 'normal deyim gibi';
+$strSearchOption4 = 'normal deyim';
 $strSearchResultsFor = ' "%s" %s için arama sonuçları:';
 $strSearchType = '<b>BUL </b> :';
 $strSecretRequired = 'Ayar dosyası için gizli bir şifre gerekiyor (blowfish_secret).';
 $strSelectADb = ' Lütfen bir veritabanı seçiniz';
 $strSelectAll = 'Tümünü seç';
+$strSelectBinaryLog = 'Görüntülemek istediğiniz binari kaydını seçiniz';  
 $strSelectFields = 'Alan seç (en az bir)';
 $strSelectNumRows = 'sorgu içerisinde';
 $strSelectTables = 'Tabloları seç';
@@ -601,11 +681,13 @@ $strSingly = '( birer birer )';
 $strSize = 'Boyut';
 $strSlovak = 'Slovakça';
 $strSlovenian = 'Slovence';
+$strSocketProblem = '(ya da lokal MySQL sunucusu soketi düzgün bir şekilde ayarlanmamış.)';
 $strSortByKey = 'Anahtara göre sırala';
 $strSort = 'Sırala';
 $strSpaceUsage = 'Kullanılan alan';
 $strSpanish = 'İspanyolca';
 $strSplitWordsWithSpace = 'Kelimelerin arasında boşluk olmalıdır (" ").';
+$strSQLExportCompatibility = 'SQL\e dönüştürme uyumluluğu';
 $strSQLExportType = 'Export tipi';
 $strSQLOptions = 'SQL seçenekleri';
 $strSQLParserBugMessage = 'SQL yorumlayıcısında bir hata bulma ihtimaliniz var.Lütfen sorgunuzu dikkatli bir şekilde gözden geçiriniz,ve tırnaklar doğru ve yanlış yazılmamış kontrol ediniz.Diğer olası hata nedenleri metin alanına alabileceği boyuttan daha büyük bir dosya yüklüyor olma ihtimalinizdir.Sorgunuzu MySQL komut satırı arayüzünde de deneyebilirsiniz..MySQL sunucu hata çıktısı,var ise,hatayı manızda size yardımcı olabilir.Hala sorunlarınız varsa veya  komut satırı arayüzü çalışırken,yorumlayıcı hata veriyorsa,lütfen SQL sorgu girişinizi hata yaratan tek bir sorguya indirgeyin,ve aşağıdaki CUT bölümü veri yığını ile birlikte hata raporunu bildiriniz:';
@@ -621,6 +703,8 @@ $strStatCreateTime = 'Oluşturulma';
 $strStatement = 'Durum';
 $strStatUpdateTime = 'Son güncellenme';
 $strStatus = 'Durum';
+$strStorageEngine = 'Depolama Motoru'; 
+$strStorageEngines = 'Depolama Motorları';  
 $strStrucCSV = 'CSV verisi';
 $strStrucData = 'Yapı ve Veri';
 $strStrucDrop = 'DROP TABLE ekle';
@@ -633,6 +717,7 @@ $strSubmit = 'Onayla';
 $strSuccess = 'SQL sorgunuz başarıyla çalıştırılmıştır';
 $strSum = 'toplam';
 $strSwedish = 'İsveçce';
+$strSwitchToDatabase = 'Kopyalanmış veritabanını kullan.';  
 $strSwitchToTable = 'Kopyalanmış tabloya geç';
 
 $strTableComments = 'Tablo yorumları';
@@ -666,6 +751,7 @@ $strTraditionalChinese = 'Geleneksel Çince';
 $strTraditionalSpanish = 'Geleneksel İspanyolca';
 $strTraffic = 'Yoğunluk';
 $strTransformation_application_octetstream__download = 'Bir alandaki binari veriyi yüklemek için link göster.İlk seçenek binari dosya adıdır.İkinci seçenek ise dosya adını içeren tablo satırırın olası alan adıdır.İkinci bir seçenek istiyorsanız ilk seçeneği boş bırakmalısınız.';
+$strTransformation_application_octetstream__hex = 'Verinin hexadesimal sunumunu gösterir.';
 $strTransformation_image_jpeg__inline = 'Tıklanabilir bir thumbnail gösterir; seçenekler: pixel olarak genişlik,yükseklik (orijinal oran korunur)';
 $strTransformation_image_jpeg__link = 'Bu resime direkt bir link gösterir (direct blob yüklemesi...).';
 $strTransformation_image_png__inline = 'jpeg resmini gör: satıriçi';
@@ -674,8 +760,8 @@ $strTransformation_text_plain__external = 'Dış bir uygulama çalıştırır ve
 $strTransformation_text_plain__formatted = 'Alanın orijinal biçimlendirmesini korur.Escaping(kaçış) yapılmaz..';
 $strTransformation_text_plain__imagelink = 'Bir resim ve bir link gösterir,alan dosya ismini içerir;ilk seçenek "http://domain.com/" gibi bir yazım,ikinci seçenek pixel olarak genişlik,üçüncüsü ise yüksekliktir.';
 $strTransformation_text_plain__link = 'Bir link ve dosya ismini içeren alanı gösterir;ilk seçenek "http://domain.com/" gibi bir gösterim,ikincisi ise link için bir başlıktır.';
+$strTransformation_text_plain__substr = 'Bir karakter dizisinin bir kısmını gösterir. İlk seçenek dizinin başlangıcından ne kadar uzağa gideceğidir (Varsayılan 0). İkinci seçenek kaç karakter alınacağıdır (Varsayılan: dizinin sonuna kadar). Üçüncü seçenek ise dizide kesilme olacaksa eklenecek ya da çıkartılacak diziyi belirtir (Varsayılan: "...").';
 $strTransformation_text_plain__substr = 'Sadece yazının bir kısmını gösterir. İlk seçenek metin çıktınızın nerede olduğunu tanımlamak için kullanılacak bir offset\'tir. (varsayılan: 0).İkinci seçenek ne kadar metinin geri döndürüldüğünü belirten bir offset\'tir.. Eğer boşsa, bütün kalan metin geri döndürülür.Üçüncü seçenek bir substring döndürüldüğünde hangi karakterlerin çıktının sonuna ekleneceğini tanımlar(Varsayılan:...) .';
-$strTransformation_text_plain__unformatted = 'HTML kodunu bir bütün olarak göster.HTML biçimlendirme gösteriliyor.';
 $strTruncateQueries = 'Görülen sorguları kısalt';
 $strTurkish = 'Türkçe';
 $strType = 'Tip';
@@ -702,6 +788,7 @@ $strUserNotFound = 'Seçili kullanıcı yetki tablosunda bulunamadı.';
 $strUserOverview = 'Kullanıcı gözlem';
 $strUsersDeleted = 'Seçili kullanıcılar başarıyla silindi.';
 $strUsersHavingAccessToDb = '&quot;%s&quot; veritabanına erişimi olan kullanıcılar';
+$strUseTabKey = 'Değerden değere geçmek için TAB tuşunu istediğiniz herhangi bir yere gitmek için CTRL+OK TUŞLARI\`nı kullanın.';
 $strUseTables = 'Tabloları kullan';
 $strUseTextField = 'Metin alanını kullan';
 $strUseThisValue = 'Bu değeri kullan';
@@ -710,16 +797,19 @@ $strValidateSQL = 'SQL\'i doğrula';
 $strValidatorError = 'SQL onaylayıcısı başlatılamadı.%sdökümanlar%s\'da belirtildiği gibi,gerekli php uzantılarının yüklenip yüklenilmediğini kontrol ediniz.';
 $strValue = 'Değer';
 $strVar = 'Değişken';
+$strVersionInformation = 'Sürüm bilgisi'; 
 $strViewDumpDatabases = 'Veritabanları döküm şeması';
 $strViewDumpDB = 'Veritabanı döküm şeması';
 $strViewDump = 'Tablo döküm şeması';
+$strView = 'Görüntü';   
+$strViewHasBeenDropped = '%s görüntüsü kaldırıldı';   
 
 $strWebServerUploadDirectoryError = 'Yükleme  için belirttiğiniz dizine ulaşılamıyor.';
 $strWebServerUploadDirectory = 'web sunucu yükleme dizini';
 $strWelcome = '%s sürümüne HOŞGELDİNİZ....';
 $strWestEuropean = 'Batı Avrupa';
 $strWildcard = 'joker';
-$strWindowNotFound = 'Hedefteki tarayı penceresi güncellenemiyor...Bağlantısı olan pencereyi kapattınız veya tarayıcınızın güvenlik ayarları buna izin vermiyor';
+$strWindowNotFound = 'Tarayı penceresi güncellenemiyor...Bağlantısı olan pencereyi kapattınız veya tarayıcınızın güvenlik ayarları buna izin vermiyor';
 $strWithChecked = 'Seçilileri:';
 $strWritingCommentNotPossible = 'Yorum yazılması mümkün değil.';
 $strWritingRelationNotPossible = 'İlişki yazılması mümkün değil.';
